==> koco_product_sqlmodel-0.1.17-py3-none-any.whl: koco_product_sqlmodel/fastapi/routes/article.py <==
from fastapi import HTTPException, Request

import koco_product_sqlmodel.dbmodels.definition as sqlm
import koco_product_sqlmodel.mdb_connect.generic_object_connect as mdb_gen
import koco_product_sqlmodel.mdb_connect.mdb_connector as mdb_con
import koco_product_sqlmodel.fastapi.routes.generic_route as rgen
import koco_product_sqlmodel.fastapi.routes.security as rsec


class ArticleRoute(rgen.MyBaseRoute):
    def __init__(
        self,
        sqlmodel_db: sqlm.SQLModel,
        sqlmodel_post: sqlm.SQLModel,
        sqlmodel_get: sqlm.SQLModel,
        tags: list[str],
    ):
        super().__init__(
            sqlmodel_db=sqlmodel_db,
            sqlmodel_post=sqlmodel_post,
            sqlmodel_get=sqlmodel_get,
            tags=tags,
        )

    async def post_object(
        self, object: sqlm.CArticlePost, request: Request
    ) -> sqlm.SQLModel:
        object.user_id = await rsec.get_user_id_from_request(request=request)
        new_obj = mdb_gen.post_object(db_obj=self.sqlmodel_db(**object.model_dump()))
        return await self.get_and_log_updated_model(
            request=request, updated_object=new_obj
        )

    async def patch_object(
        self, id: int, obj: sqlm.CArticlePost, request: Request
    ) -> sqlm.SQLModel:
        obj.user_id = await rsec.get_user_id_from_request(request=request)
        updated_object = mdb_gen.patch_object(
            id=id, db_obj=obj, db_obj_type=self.sqlmodel_db
        )
        if updated_object == None:
            raise HTTPException(status_code=404, detail="Object not found")
        return await self.get_and_log_updated_model(
            request=request, updated_object=updated_object
        )

    async def delete_object(
        self, id: int, delete_recursive: bool = True, request: Request = None
    ) -> dict[str, bool]:
        """
        Delete an article item by carticle.id.

        * Request parameter: *delete_recursive* = true

        If set to *true* all subitems contained in given article will be removed from database to avoid orphaned data
        """
        user_id = await rsec.get_user_id_from_request(request=request)
        mdb_con.delete_article_by_id(
            article_id=id, delete_connected_items=delete_recursive, user_id=user_id
        )
        return {"ok": True}


route_article = ArticleRoute(
    sqlmodel_db=sqlm.CArticle,
    sqlmodel_get=sqlm.CArticle,
    sqlmodel_post=sqlm.CArticle,
    tags=["Endpoints to ARTICLE-data"],
)


def main():
    pass


if __name__ == "__main__":
    main()

==> koco_product_sqlmodel-0.1.26-py3-none-any.whl: koco_product_sqlmodel/fastapi/routes/article.py <==
from fastapi import HTTPException, Request

import koco_product_sqlmodel.dbmodels.definition as sqlm
import koco_product_sqlmodel.mdb_connect.generic_object_connect as mdb_gen
import koco_product_sqlmodel.mdb_connect.mdb_connector as mdb_con
import koco_product_sqlmodel.fastapi.routes.generic_route as rgen
import koco_product_sqlmodel.fastapi.routes.security as rsec
from koco_product_sqlmodel.mdb_connect.import_excel import log_changes

class ArticleRoute(rgen.MyBaseRoute):
    def __init__(
        self,
        sqlmodel_db: sqlm.SQLModel,
        sqlmodel_post: sqlm.SQLModel,
        sqlmodel_get: sqlm.SQLModel,
        tags: list[str],
    ):
        super().__init__(
            sqlmodel_db=sqlmodel_db,
            sqlmodel_post=sqlmodel_post,
            sqlmodel_get=sqlmodel_get,
            tags=tags,
        )

    async def post_object(
        self, object: sqlm.CArticlePost, request: Request
    ) -> sqlm.SQLModel:
        object.user_id = await rsec.get_user_id_from_request(request=request)
        new_obj = mdb_gen.post_object(db_obj=self.sqlmodel_db(**object.model_dump()))
        return await self.get_and_log_updated_model(
            request=request, updated_object=new_obj
        )

    async def patch_object(
        self, id: int, obj: sqlm.CArticlePost, request: Request
    ) -> sqlm.SQLModel:
        obj.user_id = await rsec.get_user_id_from_request(request=request)
        updated_object = mdb_gen.patch_object(
            id=id, db_obj=obj, db_obj_type=self.sqlmodel_db
        )
        if updated_object == None:
            raise HTTPException(status_code=404, detail="Object not found")
        return await self.get_and_log_updated_model(
            request=request, updated_object=updated_object
        )

    async def delete_object(
        self, id: int, delete_recursive: bool = True, request: Request = None
    ) -> dict[str, bool]:
        """
        Delete an article item by carticle.id.

        * Request parameter: *delete_recursive* = true

        If set to *true* all subitems contained in given article will be removed from database to avoid orphaned data
        """
        user_id = await rsec.get_user_id_from_request(request=request)
        mdb_con.delete_article_by_id(
            article_id=id, delete_connected_items=delete_recursive, user_id=user_id, log_func=log_changes
        )
        return {"ok": True}


route_article = ArticleRoute(
    sqlmodel_db=sqlm.CArticle,
    sqlmodel_get=sqlm.CArticle,
    sqlmodel_post=sqlm.CArticle,
    tags=["Endpoints to ARTICLE-data"],
)


def main():
    pass


if __name__ == "__main__":
    main()
